@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -20,7 +20,7 @@
 """
 
 template_coroutine_object_maker_template = """\
-static PyObject *%(function_identifier)s_maker( void );
+static PyObject *%(function_identifier)s_maker(void);
 """
 
 template_coroutine_object_body_template = """
@@ -28,10 +28,9 @@ struct %(function_identifier)s_locals {
 %(function_local_types)s
 };
 
-static PyObject *%(function_identifier)s_context( struct Nuitka_CoroutineObject *coroutine, PyObject *yield_return_value )
-{
-    CHECK_OBJECT( (PyObject *)coroutine );
-    assert( Nuitka_Coroutine_Check( (PyObject *)coroutine ) );
+static PyObject *%(function_identifier)s_context( struct Nuitka_CoroutineObject *coroutine, PyObject *yield_return_value ) {
+    CHECK_OBJECT((PyObject *)coroutine);
+    assert(Nuitka_Coroutine_Check((PyObject *)coroutine));
 
     // Heap access if used.
 %(heap_declaration)s
@@ -48,8 +47,7 @@ static PyObject *%(function_identifier)s_context( struct Nuitka_CoroutineObject
 %(coroutine_exit)s
 }
 
-static PyObject *%(function_identifier)s_maker( void )
-{
+static PyObject *%(function_identifier)s_maker(void) {
     return Nuitka_Coroutine_New(
         %(function_identifier)s_context,
         %(coroutine_module)s,
@@ -69,18 +67,18 @@ template_make_coroutine = """\
 
 template_coroutine_exception_exit = """\
     // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE( %(function_identifier)s );
+    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
 
     function_exception_exit:
 %(function_cleanup)s\
-    assert( %(exception_type)s );
-    RESTORE_ERROR_OCCURRED( %(exception_type)s, %(exception_value)s, %(exception_tb)s );
+    assert(%(exception_type)s);
+    RESTORE_ERROR_OCCURRED(%(exception_type)s, %(exception_value)s, %(exception_tb)s);
     return NULL;
 """
 
 template_coroutine_noexception_exit = """\
     // Return statement must be present.
-    NUITKA_CANNOT_GET_HERE( %(function_identifier)s );
+    NUITKA_CANNOT_GET_HERE(%(function_identifier)s);
 
 %(function_cleanup)s\
 
@@ -96,6 +94,6 @@ template_coroutine_return_exit = """\
 """
 
 
+from . import TemplateDebugWrapper  # isort:skip
 
-from . import TemplateDebugWrapper # isort:skip
 TemplateDebugWrapper.checkDebug(globals())
