@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -24,54 +24,44 @@ whose implementation lives here. The creation itself also lives here.
 
 from nuitka.PythonVersions import python_version
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ExpressionBases import ExpressionChildHavingBase
 from .FunctionNodes import ExpressionFunctionEntryPointBase
 from .IndicatorMixins import MarkUnoptimizedFunctionIndicatorMixin
 from .ReturnNodes import StatementReturn, StatementReturnNone
 
 
-class ExpressionMakeGeneratorObject(ExpressionChildrenHavingBase):
+class ExpressionMakeGeneratorObject(ExpressionChildHavingBase):
     kind = "EXPRESSION_MAKE_GENERATOR_OBJECT"
 
-    named_children = (
-        "generator_ref",
-    )
+    named_child = "generator_ref"
+    getGeneratorRef = ExpressionChildHavingBase.childGetter("generator_ref")
 
-    getGeneratorRef = ExpressionChildrenHavingBase.childGetter("generator_ref")
+    __slots__ = ("variable_closure_traces",)
 
-    def __init__(self, generator_ref, code_object, source_ref):
-        assert generator_ref.getFunctionBody().isExpressionGeneratorObjectBody(), generator_ref
+    def __init__(self, generator_ref, source_ref):
+        assert (
+            generator_ref.getFunctionBody().isExpressionGeneratorObjectBody()
+        ), generator_ref
 
-        ExpressionChildrenHavingBase.__init__(
-            self,
-            values     = {
-                "generator_ref" : generator_ref,
-            },
-            source_ref = source_ref
+        ExpressionChildHavingBase.__init__(
+            self, value=generator_ref, source_ref=source_ref
         )
 
-        self.code_object = code_object
-
         self.variable_closure_traces = None
 
-    def getDetails(self):
-        return {
-            "code_object" : self.code_object
-        }
-
     def getCodeObject(self):
         return self.code_object
 
     def computeExpression(self, trace_collection):
         self.variable_closure_traces = []
 
-        for closure_variable in self.getGeneratorRef().getFunctionBody().getClosureVariables():
+        for closure_variable in (
+            self.getGeneratorRef().getFunctionBody().getClosureVariables()
+        ):
             trace = trace_collection.getVariableCurrentTrace(closure_variable)
             trace.addClosureUsage()
 
-            self.variable_closure_traces.append(
-                (closure_variable, trace)
-            )
+            self.variable_closure_traces.append((closure_variable, trace))
 
         # TODO: Generator body may know something too.
         return self, None, None
@@ -86,21 +76,24 @@ class ExpressionMakeGeneratorObject(ExpressionChildrenHavingBase):
         return self.variable_closure_traces
 
 
-class ExpressionGeneratorObjectBody(MarkUnoptimizedFunctionIndicatorMixin,
-                                    ExpressionFunctionEntryPointBase):
+class ExpressionGeneratorObjectBody(
+    MarkUnoptimizedFunctionIndicatorMixin, ExpressionFunctionEntryPointBase
+):
     kind = "EXPRESSION_GENERATOR_OBJECT_BODY"
 
     if python_version >= 340:
         qualname_setup = None
 
-    def __init__(self, provider, name, flags, source_ref):
+    def __init__(self, provider, name, code_object, flags, auto_release, source_ref):
         ExpressionFunctionEntryPointBase.__init__(
             self,
-            provider    = provider,
-            name        = name,
-            code_prefix = "genexpr" if name == "<genexpr>" else "genobj",
-            flags       = flags,
-            source_ref  = source_ref
+            provider=provider,
+            name=name,
+            code_object=code_object,
+            code_prefix="genexpr" if name == "<genexpr>" else "genobj",
+            flags=flags,
+            auto_release=auto_release,
+            source_ref=source_ref,
         )
 
         MarkUnoptimizedFunctionIndicatorMixin.__init__(self, flags)
@@ -113,10 +106,7 @@ class ExpressionGeneratorObjectBody(MarkUnoptimizedFunctionIndicatorMixin,
         return self.name
 
     def markAsNeedsGeneratorReturnHandling(self, value):
-        self.needs_generator_return_exit = max(
-            self.needs_generator_return_exit,
-            value
-        )
+        self.needs_generator_return_exit = max(self.needs_generator_return_exit, value)
 
     def needsGeneratorReturnHandling(self):
         return self.needs_generator_return_exit == 2
@@ -133,11 +123,7 @@ class StatementGeneratorReturn(StatementReturn):
     kind = "STATEMENT_GENERATOR_RETURN"
 
     def __init__(self, expression, source_ref):
-        StatementReturn.__init__(
-            self,
-            expression = expression,
-            source_ref = source_ref
-        )
+        StatementReturn.__init__(self, expression=expression, source_ref=source_ref)
 
     def computeStatement(self, trace_collection):
         trace_collection.onExpression(self.getExpression())
@@ -150,22 +136,27 @@ class StatementGeneratorReturn(StatementReturn):
             from .NodeMakingHelpers import makeStatementExpressionOnlyReplacementNode
 
             result = makeStatementExpressionOnlyReplacementNode(
-                expression = expression,
-                node       = self
+                expression=expression, node=self
             )
 
-            return result, "new_raise", """\
-Return statement raises in returned expression, removed return."""
+            return (
+                result,
+                "new_raise",
+                """\
+Return statement raises in returned expression, removed return.""",
+            )
 
         trace_collection.onFunctionReturn()
 
         if expression.isExpressionConstantNoneRef():
-            result = StatementGeneratorReturnNone(
-                source_ref = self.source_ref
-            )
+            result = StatementGeneratorReturnNone(source_ref=self.source_ref)
 
-            return result, "new_statements", """\
-Generator return value is always None."""
+            return (
+                result,
+                "new_statements",
+                """\
+Generator return value is always None.""",
+            )
 
         return self, None, None
 
@@ -183,10 +174,7 @@ class StatementGeneratorReturnNone(StatementReturnNone):
     __slots__ = ()
 
     def __init__(self, source_ref):
-        StatementReturnNone.__init__(
-            self,
-            source_ref = source_ref
-        )
+        StatementReturnNone.__init__(self, source_ref=source_ref)
 
     @staticmethod
     def isStatementGeneratorReturn():
