@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -37,28 +37,25 @@ class ExpressionYieldBase(ExpressionChildHavingBase):
         __slots__ = ()
 
     def __init__(self, value, source_ref):
-        ExpressionChildHavingBase.__init__(
-            self,
-            value      = value,
-            source_ref = source_ref
-        )
+        ExpressionChildHavingBase.__init__(self, value=value, source_ref=source_ref)
 
         if python_version >= 300:
             self.exception_preserving = False
 
     if python_version >= 300:
+
         def markAsExceptionPreserving(self):
             self.exception_preserving = True
 
         def isExceptionPreserving(self):
             return self.exception_preserving
+
     else:
+
         @staticmethod
         def isExceptionPreserving():
             return False
 
-    getExpression = ExpressionChildHavingBase.childGetter("expression")
-
     def computeExpression(self, trace_collection):
         trace_collection.removeKnowledge(self.getExpression())
 
@@ -85,14 +82,10 @@ class ExpressionYield(ExpressionYieldBase):
     kind = "EXPRESSION_YIELD"
 
     named_child = "expression"
+    getExpression = ExpressionChildHavingBase.childGetter("expression")
 
     def __init__(self, expression, source_ref):
-        ExpressionYieldBase.__init__(
-            self,
-            value      = expression,
-            source_ref = source_ref
-        )
-
+        ExpressionYieldBase.__init__(self, value=expression, source_ref=source_ref)
 
 
 class ExpressionYieldFrom(ExpressionYieldBase):
@@ -107,16 +100,14 @@ class ExpressionYieldFrom(ExpressionYieldBase):
         a return value is what makes Python3 generators special, and with yield
         from, that value is the expression result.
     """
+
     kind = "EXPRESSION_YIELD_FROM"
 
     named_child = "expression"
+    getExpression = ExpressionChildHavingBase.childGetter("expression")
 
     def __init__(self, expression, source_ref):
-        ExpressionYieldBase.__init__(
-            self,
-            value      = expression,
-            source_ref = source_ref
-        )
+        ExpressionYieldBase.__init__(self, value=expression, source_ref=source_ref)
 
 
 class ExpressionYieldFromWaitable(ExpressionYieldBase):
@@ -130,13 +121,11 @@ class ExpressionYieldFromWaitable(ExpressionYieldBase):
         Similar to yield from. The actual lookups of awaitable go through
         slots and have dedicated nodes.
     """
+
     kind = "EXPRESSION_YIELD_FROM_WAITABLE"
 
     named_child = "expression"
+    getExpression = ExpressionChildHavingBase.childGetter("expression")
 
     def __init__(self, expression, source_ref):
-        ExpressionYieldBase.__init__(
-            self,
-            value      = expression,
-            source_ref = source_ref
-        )
+        ExpressionYieldBase.__init__(self, value=expression, source_ref=source_ref)
