@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -23,5 +23,5 @@ print(x)
 
 print("Complex constant using sets with clashes at run time:")
 y = True
-x = ({1, }, {1, True}, {1, 1.0}, {1, y})
+x = ({1}, {1, True}, {1, 1.0}, {1, y})
 print(x)
