@@ -15,14 +15,15 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-
 def starImporterFunction():
-    from sys import *  # @UnusedWildImport
+    from sys import *
+
+    print "Version", version.split()[0].split(".")[:-1]
 
-    print "Version", version.split()[0].split('.')[:-1]
 
 starImporterFunction()
 
+
 def deepExec():
     for_closure = 3
 
@@ -40,10 +41,11 @@ def deepExec():
             print "Closure one level up was taken", for_closure_as_well
             print "Closure two levels up was taken", for_closure
             print "Globals still work", starImporterFunction
-            print "Added local from code", f  # @UndefinedVariable
+            print "Added local from code", f
 
         execFunction()
 
     deeper()
 
+
 deepExec()
