@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -19,20 +19,21 @@
 
 from __future__ import print_function
 
-import os, sys, subprocess, tempfile, shutil
+import os, sys
 
 # Find nuitka package relative to us.
 sys.path.insert(
     0,
     os.path.normpath(
-        os.path.join(
-            os.path.dirname(os.path.abspath(__file__)),
-            "..",
-            ".."
-        )
-    )
+        os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", "..")
+    ),
 )
 
+# isort:start
+
+import shutil
+import subprocess
+
 from nuitka.tools.testing.Common import check_output
 
 # Go its own directory, to have it easy with path knowledge.
@@ -67,10 +68,7 @@ for filename in sorted(os.listdir(my_dir)):
             path,
         )
 
-        result = subprocess.call(
-            command,
-            shell = True
-        )
+        result = subprocess.call(command, shell=True)
 
         if result == 2:
             sys.stderr.write("Interrupted, with CTRL-C\n")
