@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Software where
@@ -18,6 +18,10 @@
 #     limitations under the License.
 #
 
+# This test is SPECIAL. Everything in here, MUST be statically optimized,
+# and be a print of a constant, or a function that becomes a return value
+# that is constant.
+
 print(not bool)
 print(not {})
 print(not 7)
@@ -26,23 +30,6 @@ print(False or dict)
 print(type(Ellipsis))
 print("a" in "abba")
 print("a" not in "abba")
-
-# TODO: Add support for functions
-# def testInplaceOperations():
-#     x = 2
-#     x += 1
-#     x *= 2
-#     x **= 2
-#     x -= 8
-#     x //= 5
-#     x %= 3
-#     x &= 2
-#     x |= 5
-#     x ^= 1
-#     x /= 2
-#
-#     print(x)
-
 print(len("a"*10000))
 print(len(10000*"a"))
 print(len((1,) *20000))
@@ -51,3 +38,62 @@ print(len([1]*30000))
 print(len(30000*[1]))
 print(len(unicode("a")*40000))
 print(len(40000*unicode("a")))
+
+
+# For operations, we use function return values of local variables that will
+# have to become constant.
+def simpleAssignment():
+    x = 2
+    return x
+
+def inplaceOperationIncrement():
+    x = 2
+    x += 1
+    return x
+
+def inplaceOperationProduct():
+    x = 2
+    x *= 2
+    return x
+
+def inplaceOperationExponentiate():
+    x = 2
+    x **= 2
+    return x
+
+def inplaceOperationDecrement():
+    x = 2
+    x -= 8
+    return x
+
+#     x //= 5
+def inplaceOperationFloorDivison():
+    x = 2
+    x //= 5
+    return x
+
+def inplaceOperationModulus():
+    x = 2
+    x %= 3
+    return x
+
+def inplaceOperationAnd():
+    x = 2
+    x &= 2
+    return x
+
+def inplaceOperationOr():
+    x = 2
+    x |= 5
+    return x
+
+def inplaceOperationXor():
+    x = 2
+    x ^= 1
+    return x
+
+def inplaceOperationDivison():
+    x = 2
+    x /= 2
+    return x
+
