@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Software where
@@ -23,3 +23,12 @@ print( (1,2,3)[1:] )
 print( (1,2,3)[:2] )
 print( (1,2,3)[:] )
 print( (1,2,3)[1:2] )
+print( (1,2,3,4,5,6)[1::2])
+print( (1,2,3,4,5,6)[4::-2])
+print( (1,2,3,4,5,6)[-1])
+print( (1,2,3,4,5,6)[-3:])
+print( (1,2,3,4,5,6)[:-1])
+print( (1,2,3,4,5,6)[::])
+print( (1,2,3,4,5,6)[-3:-1])
+print( (1,2,3,4,5,6)[:-1:2])
+print( (1,2,3,4,5,6)[-1::-2])
