@@ -15,4 +15,10 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+""" Just trace the import.
+
+"""
+
+from __future__ import print_function
+
 print("This is for relative import.")
