@@ -19,12 +19,16 @@
 #
 from __future__ import print_function
 
+import sys
+
+from PyQt5.QtCore import QCoreApplication
+from PyQt5.QtCore import QSettings
+from PyQt5.QtCore import QMetaObject, QObject, pyqtSignal, pyqtSlot
+
 # This test is playing with configuration settings and checking that works.
 
-from PyQt5.QtCore import QSettings  # @UnresolvedImport
-from PyQt5.QtCore import QCoreApplication  # @UnresolvedImport
 
-import sys
+# nuitka-skip-unless-imports: PyQt5.QtGui
 
 app = QCoreApplication([])
 app.setOrganizationName("BOGUS_NAME")
@@ -35,25 +39,27 @@ print("OK.")
 # This test is using signals and will only work if PySide properly accepts
 # compiled functions as callables.
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, QObject, QMetaObject
 
 class Communicate(QObject):
     speak = pyqtSignal(int)
-    def __init__(self,name = "",parent = None):
-        QObject.__init__(self,parent)
+
+    def __init__(self, name="", parent=None):
+        QObject.__init__(self, parent)
         self.setObjectName(name)
 
+
 class Speaker(QObject):
     @pyqtSlot(int)
     def on_communicator_speak(self, stuff):
         print(stuff)
 
+
 speaker = Speaker()
-someone = Communicate(name = "communicator",parent = speaker)
+someone = Communicate(name="communicator", parent=speaker)
 
 QMetaObject.connectSlotsByName(speaker)
 
-print("The answer is:",end = "")
+print("The answer is:", end="")
 # emit  'speak' signal
 someone.speak.emit(42)
 print("Slot should have made output by now.")
