@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -16,5 +16,4 @@
 #     limitations under the License.
 #
 
-x = (i for i in
-(yield from range(7)) if (yield from range(2)))
+x = (yield from range(8))
